import 'package:flutter/material.dart';

class PhoenixButton extends StatelessWidget {
  const PhoenixButton({
    Key? key,
    required this.text,
    this.buttonColor,
    this.buttonElevation,
    this.textColor,
    this.disableButtonColor,
    this.textScaleFactor,
    this.onPressed,
    this.radius,
    this.fontSize,
    this.fontWeight,
    this.marginLeft,
    this.marginRight,
    this.marginTop,
    this.marginBottom,
    this.paddingLeft,
    this.paddingRight,
    this.paddingTop,
    this.paddingBottom,
    this.height,
    this.width,
    this.textAlign,
  }) : super(key: key);

  final String text;
  final Color? buttonColor;
  final Color? textColor;
  final Color? disableButtonColor;
  final double? buttonElevation;
  final double? textScaleFactor;
  final double? radius;
  final double? fontSize;
  final double? marginLeft;
  final double? marginRight;
  final double? marginTop;
  final double? marginBottom;
  final double? paddingLeft;
  final double? paddingRight;
  final double? paddingTop;
  final double? paddingBottom;
  final double? height;
  final double? width;
  final FontWeight? fontWeight;
  final VoidCallback? onPressed;
  final TextAlign? textAlign;

  @override
  Widget build(BuildContext context) {
    return Container(
        width: width ?? double.infinity,
        height: height,
        margin: EdgeInsets.only(
            left: marginLeft ?? 0.0,
            right: marginRight ?? 0.0,
            top: marginTop ?? 0.0,
            bottom: marginBottom ?? 0.0),
        child: ElevatedButton(
            style: ElevatedButton.styleFrom(
              primary: buttonColor,
              onPrimary: textColor,
              // elevation: buttonElevation ?? 0.0,
              onSurface:
                  disableButtonColor ?? Colors.greenAccent.withOpacity(0.5),
              shape: RoundedRectangleBorder(
                  borderRadius:
                      BorderRadius.all(Radius.circular(radius ?? 0.0))),
            ),
            onPressed: onPressed,
            child: Container(
              width: width ?? double.infinity,
              padding: EdgeInsets.only(
                  left: paddingLeft ?? 0.0,
                  right: paddingRight ?? 0.0,
                  top: paddingTop ?? 0.0,
                  bottom: paddingBottom ?? 0.0),
              child: Text(
                text,
                textAlign: textAlign ?? TextAlign.center,
                textScaleFactor: textScaleFactor ?? 1.0,
                style: TextStyle(
                    fontSize: fontSize ?? 14.0,
                    fontWeight: fontWeight ?? FontWeight.normal,
                    color: textColor ?? Colors.white),
              ),
            )));
  }
}
