import 'package:flutter/material.dart';

class PhoenixProductTiles extends StatelessWidget {
  const PhoenixProductTiles({
    Key? key,
    required this.items,
    required this.onTap,
    this.crossAxisCount = 4
  }) : super(key: key);

  final List<PhoenixProductItem> items;
  final void Function(int) onTap;
  final int crossAxisCount;

  @override
  Widget build(BuildContext context) {
    return SliverPadding(
      padding: const EdgeInsets.fromLTRB(16.0, 20.0, 16.0, 0.0),
      sliver: SliverGrid(
          delegate: SliverChildBuilderDelegate((context, index) {
            var item = items[index];
            return _PhoenixProductTile(
              icon: item.icon,
              title: item.title,
              index: items.indexOf(item),
              onTap: onTap,
            );
          }, childCount: items.length),
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: crossAxisCount,
          )),
    );
  }
}

class _PhoenixProductTile extends StatelessWidget {
  const _PhoenixProductTile({
    Key? key,
    required this.icon,
    required this.title,
    required this.index,
    required this.onTap,
  }) : super(key: key);

  final Image icon;
  final String title;
  final int index;
  final void Function(int) onTap;

  @override
  Widget build(BuildContext context) {
    return TextButton(
        style: TextButton.styleFrom(
          padding: EdgeInsets.zero,
        ),
        onPressed: () {
          onTap(index);
        },
        child: Column(
          children: [
            CircleAvatar(
              child: icon,
              backgroundColor: const Color(0x1A67C1BF)
            ),
            Container(
              margin: const EdgeInsets.only(top: 8.0),
              child: Text(
                title,
                textAlign: TextAlign.center,
                style: Theme.of(context).textTheme.caption,
              ),
            )
          ],
        ));
  }
}

class PhoenixProductItem {
  final String title;
  final Image icon;

  PhoenixProductItem(this.title, this.icon);
}
